maus package
============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   maus.models
   maus.reader

Module contents
---------------

.. automodule:: maus
   :members:
   :undoc-members:
   :show-inheritance:
